@@ -1,9 +1,9 @@
 (*
    PCRE-OCAML - Perl Compatibility Regular Expressions for OCaml
 
-   Copyright (C) 1999-2003  Markus Mottl
-   email: markus@oefai.at
-   WWW:   http://www.oefai.at/~markus
+   Copyright (C) 1999-2005  Markus Mottl
+   email: markus.mottl@gmail.com
+   WWW:   http://www.ocaml.info
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
-(* $Id: pcre.ml,v 1.19 2004/04/29 13:23:38 mottl Exp $ *)
+(* $Id: pcre.ml,v 1.22 2005/06/08 23:42:14 mottl Exp $ *)
 
 
 (* Public exceptions and their registration with the C runtime *)
@@ -193,9 +193,7 @@ external nameentrysize : regexp -> int = "pcre_nameentrysize_stub"
 external firstbyte : regexp -> firstbyte_info = "pcre_firstbyte_stub"
 external firsttable : regexp -> string option = "pcre_firsttable_stub"
 external lastliteral : regexp -> char option = "pcre_lastliteral_stub"
-
-external study_stat :
-  regexp -> study_stat = "pcre_study_stat_stub" "noalloc"
+external study_stat : regexp -> study_stat = "pcre_study_stat_stub" "noalloc"
 
 
 (* Compilation of patterns *)
@@ -323,7 +321,7 @@ external unsafe_pcre_exec :
 let make_ovector rex =
   let subgroups1 = capturecount rex + 1 in
   let subgroups2 = subgroups1 lsl 1 in
-  subgroups2, Array.create (subgroups1 + subgroups2) 0
+  subgroups2, Array.make (subgroups1 + subgroups2) 0
 
 let pcre_exec ?(iflags = 0) ?flags ?(rex = def_rex) ?pat ?(pos = 0)
               ?callout subj =
@@ -347,25 +345,27 @@ let rec copy_lst ar n = function
   | [] -> ar
   | h :: t -> Array.unsafe_set ar n h; copy_lst ar (n - 1) t
 
-let rec exec_all_aux lst n iflags rex ?callout (subj, ovector as sstrs) =
-  match
-    try
-      let pos = Array.unsafe_get ovector 1 in
-      Some (subj, pcre_exec ~iflags ~rex ~pos ?callout subj)
-    with Not_found -> None
-  with
-    | Some sstrs ->
-        exec_all_aux (sstrs :: lst) (n + 1) iflags rex ?callout sstrs
-    | None ->
-        match lst with
-        | _ :: t -> copy_lst (Array.create n sstrs) (n - 2) t
-        | _ -> assert false (* impossible *)
-
 let exec_all ?(iflags = 0) ?flags ?(rex = def_rex) ?pat ?pos ?callout subj =
   let rex = match pat with Some str -> regexp str | _ -> rex in
   let iflags = match flags with Some flags -> rflags flags | _ -> iflags in
-  let sstrs = exec ~iflags ~rex ?pos ?callout subj in
-  exec_all_aux [sstrs] 1 iflags rex ?callout sstrs
+  let (_, ovector as sstrs) = exec ~iflags ~rex ?pos ?callout subj in
+  let null_flags = iflags lor 0x0400 in
+  let subj_len = String.length subj in
+  let rec loop pos (subj, ovector as sstrs) n lst =
+    let maybe_ovector =
+      try
+        let first = Array.unsafe_get ovector 0 in
+        if first = pos && Array.unsafe_get ovector 1 = pos then
+          if pos = subj_len then None
+          else Some (pcre_exec ~iflags:null_flags ~rex ~pos ?callout subj)
+        else Some (pcre_exec ~iflags ~rex ~pos ?callout subj)
+      with Not_found -> None in
+    match maybe_ovector with
+    | Some ovector ->
+        let new_pos = Array.unsafe_get ovector 1 in
+        loop new_pos (subj, ovector) (n + 1) (sstrs :: lst)
+    | None -> copy_lst (Array.make (n + 1) sstrs) (n - 1) lst in
+  loop (Array.unsafe_get ovector 1) sstrs 0 []
 
 let extract ?iflags ?flags ?rex ?pat ?pos ?full_match ?callout subj =
   get_substrings ?full_match (exec ?iflags ?flags ?rex ?pat ?pos ?callout subj)
@@ -781,15 +781,19 @@ let internal_psplit flags rex max pos callout subj =
               if last = pos then
                 let strs = if prematch then handle_subgroups strs else strs in
                 if len = 0 then "" :: strs
-                else
+                else if
                   try
-                    unsafe_pcre_exec (flags lor 0x0410) rex pos subj
-                                      subgroups2 ovector callout;
-                    let new_strs = handle_subgroups ("" :: strs) in
-                    loop new_strs (cnt - 1) (Array.unsafe_get ovector 1) false
-                  with Not_found ->
-                    let new_strs = string_unsafe_sub subj pos 1 :: strs in
-                    loop new_strs (cnt - 1) (pos + 1) true
+                    unsafe_pcre_exec
+                      (flags lor 0x0410) rex pos subj
+                      subgroups2 ovector callout;
+                    true
+                  with Not_found -> false
+                then
+                  let new_strs = handle_subgroups ("" :: strs) in
+                  loop new_strs (cnt - 1) (Array.unsafe_get ovector 1) false
+                else
+                  let new_strs = string_unsafe_sub subj pos 1 :: strs in
+                  loop new_strs (cnt - 1) (pos + 1) true
               else
                 if prematch then loop (handle_subgroups strs) cnt last false
                 else loop (handle_subgroups ("" :: strs)) (cnt - 1) last false
@@ -899,9 +903,14 @@ let full_split ?(iflags = 0) ?flags ?(rex = def_rex) ?pat
                 if len = 0 then handle_subgroups (Delim "" :: strs)
                 else
                   let empty_groups = handle_subgroups [] in
-                  try
-                    unsafe_pcre_exec (iflags lor 0x0410) rex pos subj
-                                      subgroups2 ovector callout;
+                  if
+                    try
+                      unsafe_pcre_exec
+                        (iflags lor 0x0410) rex pos subj
+                        subgroups2 ovector callout;
+                      true
+                    with Not_found -> false
+                  then
                     let first = Array.unsafe_get ovector 0 in
                     let last = Array.unsafe_get ovector 1 in
                     let delim =
@@ -911,7 +920,7 @@ let full_split ?(iflags = 0) ?flags ?(rex = def_rex) ?pat
                         delim :: (if prematch then strs
                                   else empty_groups @ (Delim "" :: strs))) in
                     loop new_strs (cnt - 1) last false
-                  with Not_found ->
+                  else
                     let new_strs =
                       Text (string_unsafe_sub subj pos 1)
                         :: empty_groups @ Delim "" :: strs in
