@@ -1,9 +1,9 @@
 (*
    PCRE-OCAML - Perl Compatibility Regular Expressions for OCaml
 
-   Copyright (C) 1999-2003  Markus Mottl
-   email: markus@oefai.at
-   WWW:   http://www.oefai.at/~markus
+   Copyright (C) 1999-2005  Markus Mottl
+   email: markus.mottl@gmail.com
+   WWW:   http://www.ocaml.info
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
-(* $Id: pcre.mli,v 1.19 2004/04/29 13:23:38 mottl Exp $ *)
+(* $Id: pcre.mli,v 1.21 2005/07/07 14:16:43 mottl Exp $ *)
 
 (** Perl Compatibility Regular Expressions *)
 
@@ -559,7 +559,6 @@ val pmatch :
     @param rex default = matches whitespace
     @param pat default = ignored
     @param pos default = 0
-    @param full_match default = true
     @param callout default = ignore callouts *)
 
 
