@@ -1,9 +1,9 @@
 /*
    PCRE-OCAML - Perl Compatibility Regular Expressions for OCaml
 
-   Copyright (C) 1999-2003  Markus Mottl
-   email: markus@oefai.at
-   WWW:   http://www.oefai.at/~markus
+   Copyright (C) 1999-2005  Markus Mottl
+   email: markus.mottl@gmail.com
+   WWW:   http://www.ocaml.info
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: pcre_stubs.c,v 1.20 2004/02/21 21:27:11 mottl Exp $ */
+/* $Id: pcre_stubs.c,v 1.23 2005/06/08 23:42:14 mottl Exp $ */
 
 #if defined(_WIN32) && defined(_DLL)
 #  define PCREextern __declspec(dllexport)
@@ -118,7 +118,7 @@ static int pcre_callout_handler(pcre_callout_block* cb)
 
 /* Fetchs the named OCaml-values + caches them and
    calculates + caches the variant hash values */
-CAMLprim value pcre_ocaml_init()
+CAMLprim value pcre_ocaml_init(value unit)
 {
   pcre_exc_Not_found     = caml_named_value("Pcre.Not_found");
   pcre_exc_BadPattern    = caml_named_value("Pcre.BadPattern");
@@ -146,7 +146,7 @@ static void pcre_dealloc_tables(value v_table)
 /* Finalizing deallocation function for compiled regular expressions */
 static void pcre_dealloc_regexp(value v_rex)
 {
-  void *extra = (void *) Field(v_rex,2);
+  void *extra = (void *) Field(v_rex, 2);
   (pcre_free)((void *) Field(v_rex, 1));
   if (extra != NULL) (pcre_free)(extra);
 }
@@ -169,7 +169,7 @@ static void raise_with_two_args(value tag, value arg1, value arg2)
 }
 
 /* Makes OCaml-string from PCRE-version */
-CAMLprim value pcre_version_stub() {
+CAMLprim value pcre_version_stub(value unit) {
   return copy_string((char *) pcre_version());
 }
 
@@ -225,7 +225,7 @@ CAMLprim value pcre_study_stub(value v_rex)
     pcre_extra *extra = pcre_study((pcre *) Field(v_rex, 1), 0, &error);
     if (error != NULL) invalid_argument((char *) error);
     Field(v_rex, 2) = (value) extra;
-    ++Field(v_rex, 3);
+    Field(v_rex, 3) = Val_int(1);
   }
   return v_rex;
 }
@@ -514,7 +514,7 @@ CAMLprim value pcre_exec_stub_bc(value *argv, int argn)
 
 /* Generates a new set of chartables for the current locale (see man
    page of PCRE */
-CAMLprim value pcre_maketables_stub()
+CAMLprim value pcre_maketables_stub(value unit)
 {
   /* GC will do a full cycle every 100 table set allocations
      (one table set consumes 864 bytes -> maximum of 86400 bytes
@@ -550,21 +550,21 @@ static int pcre_config_int(int what)
 /* Some stubs for config-functions */
 
 /* Returns boolean indicating UTF8-support */
-CAMLprim value pcre_config_utf8_stub()
+CAMLprim value pcre_config_utf8_stub(value unit)
 { return Val_bool(pcre_config_int(PCRE_CONFIG_UTF8)); }
 
 /* Returns character used as newline */
-CAMLprim value pcre_config_newline_stub()
+CAMLprim value pcre_config_newline_stub(value unit)
 { return Val_int(pcre_config_int(PCRE_CONFIG_NEWLINE)); }
 
 /* Returns number of bytes used for internal linkage of regular expressions */
-CAMLprim value pcre_config_link_size_stub()
+CAMLprim value pcre_config_link_size_stub(value unit)
 { return Val_int(pcre_config_int(PCRE_CONFIG_LINK_SIZE)); }
 
 /* Returns default limit for calls to internal matching function */
-CAMLprim value pcre_config_match_limit_stub()
+CAMLprim value pcre_config_match_limit_stub(value unit)
 { return Val_int(pcre_config_int(PCRE_CONFIG_MATCH_LIMIT)); }
 
 /* Returns boolean indicating use of stack recursion */
-CAMLprim value pcre_config_stackrecurse_stub()
+CAMLprim value pcre_config_stackrecurse_stub(value unit)
 { return Val_bool(pcre_config_int(PCRE_CONFIG_STACKRECURSE)); }
